@@ -42,7 +42,9 @@ def getNeighbor(natom,r,rcut,bo,botol=0.0):
     neighbors = [[] for _ in range(natom)]
     for i in range(natom-1):
         for j in range(i+1,natom):
+            # print(i,j,r[i][j],rcut[i][j])
             if r[i][j]<rcut[i][j] and bo[i][j]>=botol:
+               # print(i,j)
                neighbors[i].append(j)
                neighbors[j].append(i)
     return neighbors
@@ -111,6 +113,9 @@ def get_zmat_angle(i,j,k,positions):
     ukj  = vkj/rkj
 
     cos_ = np.dot(uij,ukj)
+    if cos_>1.0: cos_=1.0
+    if cos_<-1.0: cos_=-1.0
+
     ang  = np.arccos(cos_)*180.0/3.141593
     return rij,ang
 
@@ -488,9 +493,9 @@ class AtomDance(object):
              else:
                 sign = -1.0
              self.BondDistrubed.append(bd)
-             atoms = self.set_bond_momenta(i,j,atoms,sign=sign)
-             return atoms,bd
-      return atoms,None
+             atoms,groupi,groupj = self.set_bond_momenta(i,j,atoms,sign=sign)
+             return atoms,bd,groupi,groupj
+      return atoms,None,[],[]
 
   def set_bond_momenta(self,i,j,atoms,sign=1.0):
       ha      = int(0.5*self.natom)
@@ -526,7 +531,7 @@ class AtomDance(object):
       for a in group_j:
           v[a] = -sign*vj*vij
       atoms.set_velocities(v)
-      return atoms
+      return atoms,group_i,group_j
       
   def zmat_relax(self,atoms,nbin=10,relax_step=None,
                  zmat_variable=None,zvlo=None,zvhi=None,
@@ -1024,6 +1029,43 @@ class AtomDance(object):
       if not traj is None: his.close()
       return images
 
+
+  def continous(self,atoms,dr=0.001,da=1.0):
+      ''' check the continous of the PES of the current configuration '''
+      de = np.zeros((self.natom,3,2))
+      # images = []
+      zmatrix = np.array(get_zmatrix(atoms,self.zmat_id,self.zmat_index))
+      self.ir.calculate(atoms)
+      e       = self.ir.E
+      for i_,i in enumerate(self.zmat_id):
+          for j_,j in enumerate(self.zmat_index[i_]):
+              if j!=-1:
+                 if j_ == 0 :
+                    d_ = dr 
+                 else: 
+                    d_ = da
+                 for k_,k in enumerate([-1.0,1.0]):
+                     d = d_*k
+                     atoms_ = atoms.copy()
+                     zmat_  = zmatrix.copy()
+                     zmat_[i_][j_] = zmatrix[i_][j_] + d
+                     # print(i_,j_,d,zmat_[i_][j_],zmatrix[i_][j_])
+                     
+                     atoms_ = self.zmat_to_cartation(atoms_,zmat_)
+                     self.ir.calculate(atoms_)
+
+                     e_ = self.ir.E
+                     dE = e_-e
+                     de[i_][j_][k_] = dE
+
+                     calc = SinglePointCalculator(atoms_,energy=self.ir.E)
+                     atoms_.set_calculator(calc)
+                     # images.append(atoms_)
+                     del atoms_
+                     del zmat_
+      return de # ,images
+
+
   def scan_pes(self,i,n,neighbor,atoms,images,r,nbin=[5],dr=[0.1]):
       if n>=len(neighbor):
          return None
