@@ -5,22 +5,25 @@ email: fengguo@lcu.edu.cn
        gfeng.alan@foxmail.com
 
 This software package is under academic license.
+  2021-05-11:
+     A new restricted molecular dynamic simulation methond has implemented to 
+  seach the configration space. 
   2020-02-01:
-     version 3.8 Massage passing mode  introduced
+     version 0.8 Massage passing mode  introduced
   2019-11-01:
-     version 3.7 Support TensorFlow-2.0
+     version 0.7 Support TensorFlow-2.0
   2019-09-18:
-     version 3.6 supporting for triclinic crystal strucutres
+     version 0.6 supporting for triclinic crystal strucutres
   2019-08-05:
-     version 3.5 opitimize ReaxFF-QEq parameters with machine learning
+     version 0.5 opitimize ReaxFF-QEq parameters with machine learning
      
   2019-05-06:
-     version 3.3 fix bugs of NLP, PBO calculation 
+     version 0.3 fix bugs of NLP, PBO calculation 
                           Delta_angle index error
   2019-04-16
-     version 3.2 weight added
+     version 0.2 weight added
   2019-04-02:
-     version 3.1 change log, test of torsion energies,
+     version 0.1 change log, test of torsion energies,
      found eover and eunder bugs(fixed)
      add penalty for case of bond-order to small
 
