@@ -25,8 +25,7 @@ def SinglePointEnergies(traj,label='aimd',xcf='VDW',xca='DRSLL',basistype='DZP',
     if len(ind_)>1 and 0 in ind_:
        ind_.pop(0)
 
-    his = TrajectoryWriter(label+'.traj',mode='w')
-    # print(frame,ind_)
+    his      = TrajectoryWriter(label+'.traj',mode='w')
     energies = []
     d2Es     = []
     dE_      = 0.0
@@ -43,18 +42,15 @@ def SinglePointEnergies(traj,label='aimd',xcf='VDW',xca='DRSLL',basistype='DZP',
            else:
               deltEl =  energy - energies[-1]
               dE_ = abs(deltEl)
-
+        
         energies.append(energy)
         dEs.append(dE_)
         d2Es.append(d2E_)
-        
+
         if select:
            if dE_>dE or d2E_>d2E:
               if i not in ind_:
-                 if len(ind_)>0:
-                    if i-ind_[-1]>1:
-                       ind_.append(i)
-                 else:
+                 if i-1 not in ind_:
                     ind_.append(i)
 
     ide  = np.argmax(dEs)
