@@ -99,8 +99,8 @@ class Init_Check(object):
           if key == 'lp1':
              if p[key]>=28.0:
                 p[key] = value(20.0,key)
-             if p[key]<=12.0:
-                p[key] = value(16.0,key)
+             # if p[key]<=12.0:
+             #    p[key] = value(16.0,key)
 
           if k=='lp2':
              sp = key.split('_')[1]
@@ -168,7 +168,7 @@ class Init_Check(object):
              tor= pr.split('-')
              if tor[1]=='H' or tor[2]=='H':
                 p[key] = value(0.0,key)
-             if p[key]>=99.0:
+             if p[key]>=120.0:
                 p[key] = value(90.0,key)
              if p[key]<=-60.0:
                 p[key] = value(60.0,key)
@@ -270,10 +270,10 @@ class Init_Check(object):
              if p[key]>=20.00:
                 p[key]= value(2.0,key)
           if k=='ovun5': 
-             if p[key]>=100.0:
+             if p[key]>=90.0:
                 p[key]= value(49.0,key)
              if p[key]<=0.001:
-                p[key]= value(6.0,key)
+                p[key]= value(0.001,key)
           if k in ['bo2','bo4','bo6']:     ### scale bo
              if p[key]>=8.0:
                 p[key] = value(7.95,key)
