@@ -120,7 +120,7 @@ class IRFF(Calculator):
          self.be_layer       = j['be_layer']
          self.vdw_layer      = j['vdw_layer']
          rcut                = j['rcut']
-         rcuta               = j['rcutAngle']
+         rcuta               = j['rcutBond']
          lf.close()
          self.init_bonds()
          if mol is None:
