@@ -67,30 +67,33 @@ class IRMD(object):
                initT=300,Tmax=10000,time_step=0.1,Iter=0,
                ro=None,rmin=0.6,rmax=1.3,angmax=20.0,
                UseZmat=False,zmat_id=None,zmat_index=None,InitZmat=None,
-               learnpair=None,beta=None,
-               dEstop=0.5,print_interval=1):
-      self.Epot    = []
-      self.epot    = 0.0
-      self.ekin    = 0.0
-      self.T       = 0.0
-      self.initT   = initT
-      self.Tmax    = Tmax
-      self.totstep = totstep
-      self.ro      = ro
-      self.rmin    = rmin
-      self.Iter    = Iter
-      self.atoms   = atoms
+               learnpair=None,groupi=[],groupj=[],beta=None,
+               dEstop=1000,dEtole=1.0,print_interval=1):
+      self.Epot      = []
+      self.epot      = 0.0
+      self.ekin      = 0.0
+      self.T         = 0.0
+      self.initT     = initT
+      self.Tmax      = Tmax
+      self.totstep   = totstep
+      self.ro        = ro
+      self.rmin      = rmin
+      self.Iter      = Iter
+      self.atoms     = atoms
       self.time_step = time_step
-      self.step    = 0
-      self.rmax    = rmax
-      self.angmax  = angmax
-      self.UseZmat = UseZmat
+      self.step      = 0
+      self.rmax      = rmax
+      self.angmax    = angmax
+      self.UseZmat   = UseZmat
       self.zmat_id   = zmat_id
       self.zmat_index= zmat_index
       self.InitZmat  = InitZmat
       self.zmats     = []
       self.dEstop    = dEstop
+      self.dEtole    = dEtole
       self.learnpair = learnpair
+      self.groupi    = groupi
+      self.groupj    = groupj
       self.beta      = beta
       self.print_interval = print_interval
 
@@ -125,24 +128,53 @@ class IRMD(object):
          rij = np.sqrt(np.sum(np.square(vij)))
          vij = vij/rij
 
+      self.dEstop_ = 0.0
+
       def printenergy(a=self.atoms):
           n             = 0
           self.Deformed = 0.0
           epot_         = a.get_potential_energy()
+          v             = self.atoms.get_velocities()
 
           if (not self.learnpair is None) and (not self.beta is None):
-             v    = self.atoms.get_velocities()
-             # vv   = np.sqrt(np.sum(np.square(v),axis=1))
+             # v  = np.sqrt(np.sum(np.square(v),axis=1))
+             di   = np.dot(v[self.learnpair[0]],vij)
+             dj   = np.dot(v[self.learnpair[1]],vij)
              for iv,v_ in enumerate(v):
                  d  = np.dot(v_,vij)
-                 vd = d*vij
-                 v[iv] = vd + self.beta*(v[iv]-vd)
+                 d_ = d
+                 if iv in self.groupi:
+                    if abs(d)>abs(di):
+                       if abs(d*self.beta)>abs(di):
+                          d_=d*self.beta
+                       else:
+                          d_=di
+                 elif iv in self.groupj:
+                    if abs(d)>abs(dj):
+                       if abs(d*self.beta)>abs(dj):
+                          d_=d*self.beta
+                       else:
+                          d_=dj
+                 vd  = d*vij
+                 vd_ = d_*vij
+                 v[iv] = vd_ + self.beta*(v[iv]-vd)
              self.atoms.set_velocities(v)
 
           if self.UseZmat:
              self.Deformed,zmat,self.zv,self.zvlo,self.zvhi = check_zmat(atoms=a,rmin=self.rmin,rmax=self.rmax,
                                              angmax=self.angmax,zmat_id=self.zmat_id,
                                              zmat_index=self.zmat_index,InitZmat=self.InitZmat)
+             if not self.zv is None:
+                if self.zv[1] == 0:
+                   df_i = self.zmat_id[self.zv[0]]
+                   df_j = self.zmat_index[self.zv[0]][0]
+                   v[df_i][0] = 0.0 
+                   v[df_i][1] = 0.0 
+                   v[df_i][2] = 0.0 
+                   v[df_j][0] = 0.0 
+                   v[df_j][1] = 0.0 
+                   v[df_j][2] = 0.0 
+                   self.atoms.set_velocities(v)
              bonds      = getBonds(self.natom,self.atoms.calc.r,1.22*self.re)
              newbond    = self.checkBond(bonds)
              if newbond: 
@@ -176,6 +208,9 @@ class IRMD(object):
              dE_ = 0.0
           else:
              dE_ = abs(epot_ - self.Epot[-1])
+          if dE_>self.dEtole:
+             self.dEstop_ += dE_
+
           self.Epot.append(epot_)
 
           self.epot  = epot_/self.natom
@@ -188,9 +223,9 @@ class IRMD(object):
                                    self.epot + self.ekin))
           try:
              if self.UseZmat:
-                assert self.Deformed<1,'Atoms structure is deformed!' 
+                assert self.Deformed<1 and self.dEstop_<self.dEstop,'Atoms structure is deformed!' 
              else:
-                assert n==0 and self.T<self.Tmax,'Atoms too closed or Temperature goes too high!' 
+                assert n==0 and self.T<self.Tmax and self.dEstop_<self.dEstop,'Atoms too closed or Temperature goes too high!' 
           except:
              # for _ in i_:
              #     print('atoms pair',_)
@@ -198,6 +233,10 @@ class IRMD(object):
                  print('Atoms too closed, stop at %d.' %self.step)
              elif self.Deformed>=1.0: 
                  print('Structure Deformed = %f exceed the limit, stop at %d.' %(self.Deformed,self.step))
+             elif self.dEstop_>self.dEstop:
+                  print('The sum of dE = %f exceed the limit, stop at %d.' %(self.dEstop_,self.step))
+             elif self.T>self.Tmax:
+                  print('Temperature = %f too high!, stop at %d.' %(self.T,self.step))
              else:
                  print('unknown reason, stop at %d.' %self.step)
              self.dyn.max_steps = self.dyn.nsteps-1
