@@ -26,8 +26,11 @@ tf.compat.v1.disable_eager_execution()
 class MPNN(ReaxFF):
   def __init__(self,libfile='ffield',direcs={},
                dft='ase',atoms=None,
-               cons=['val','vale','rosi','ropi','ropp', # 'ovun3', # 'val8','val9','val10',
-                     'bo1','bo2','bo3','bo4','bo5','bo6','Depi','Depp','lp3'], # 'hbtol'
+               cons=['val','vale',
+                     # 'rosi','ropi','ropp', 
+                     # 'ovun3', # 'val8','val9','val10',
+                     # 'bo1','bo2','bo3','bo4','bo5','bo6',
+                     'Depi','Depp','lp3','cutoff'], # 'hbtol'
                optmol=True,mefac=0.1,
                opt=None,optword='nocoul',
                nanv={'boc1':-2.0},
@@ -115,7 +118,7 @@ class MPNN(ReaxFF):
   def supervise(self):
       ''' supervised learning term'''
       l_atol = 0.0
-      self.diffa,self.diffb,self.diffe,self.diffesi = {},{},{},{}
+      self.diffn,self.diffa,self.diffb,self.diffe,self.diffesi = {},{},{},{},{}
       for bd in self.bonds: 
           [atomi,atomj] = bd.split('-') 
           if self.nbd[bd]>0:
@@ -129,10 +132,10 @@ class MPNN(ReaxFF):
              else:
                 bm_ = self.bom['others']
              
-             if not self.TwoBodyOnly:
-                fao = tf.where(tf.greater(self.rbd[bd],self.rcuta[bd]),1.0,0.0)    ##### r> rcuta that bo = 0.0
-                self.diffa[bd]  = tf.reduce_sum(input_tensor=tf.nn.relu(self.bo0[bd]*fao-self.atol))
-                l_atol = tf.add(self.diffa[bd],l_atol)
+             # if not self.TwoBodyOnly:
+             fao = tf.where(tf.greater(self.rbd[bd],self.rcuta[bd]),1.0,0.0)    ##### r> rcuta that bo = 0.0
+             self.diffn[bd]  = tf.reduce_sum(input_tensor=tf.nn.relu(self.bo0[bd]*fao-self.botol)) # self.atol
+             l_atol = tf.add(self.diffn[bd],l_atol)
 
              if self.spv_bm:
                 fao_= tf.where(tf.less_equal(self.rbd[bd],bm_*self.re[bd]),1.0,0.0) ##### r< 1.2*re that bo > botol
@@ -348,33 +351,33 @@ class MPNN(ReaxFF):
       bdr     = b[1]+'-'+b[0]
       flabel  = 'f'+str(t)
       if self.MessageFunction==1:
-         Fi      = self.f_nn(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
-         Fj      = self.f_nn(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
-         F       = 2.0*Fi*Fj
+         Fi    = self.f_nn(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
+         Fj    = self.f_nn(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
+         F     = 2.0*Fi*Fj
        
-         bosi    = self.Hsi[t-1][bd]*F
-         bopi    = self.Hpi[t-1][bd]*F
-         bopp    = self.Hpp[t-1][bd]*F
+         bosi  = self.Hsi[t-1][bd]*F
+         bopi  = self.Hpi[t-1][bd]*F
+         bopp  = self.Hpp[t-1][bd]*F
       elif self.MessageFunction==2:
-         Fi      = self.fmassage(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
-         Fj      = self.fmassage(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
-         F       = Fi*Fj
+         Fi    = self.fmassage(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
+         Fj    = self.fmassage(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
+         F     = Fi*Fj
          Fsi,Fpi,Fpp = tf.unstack(F,axis=2)
        
-         bosi    = self.Hsi[t-1][bd]*Fsi
-         bopi    = self.Hpi[t-1][bd]*Fpi
-         bopp    = self.Hpp[t-1][bd]*Fpp
+         bosi  = self.Hsi[t-1][bd]*Fsi
+         bopi  = self.Hpi[t-1][bd]*Fpi
+         bopp  = self.Hpp[t-1][bd]*Fpp
       elif self.MessageFunction==3:
-         Fi      = self.f_nn(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
-         Fj      = self.f_nn(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
-         F       = Fi*Fj
+         Fi    = self.f_nn(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
+         Fj    = self.f_nn(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
+         F     = Fi*Fj
        
-         bosi    = self.Hsi[t-1][bd]*F
-         bopi    = self.Hpi[t-1][bd]*F
-         bopp    = self.Hpp[t-1][bd]*F
+         bosi  = self.Hsi[t-1][bd]*F
+         bopi  = self.Hpi[t-1][bd]*F
+         bopp  = self.Hpp[t-1][bd]*F
       else:
          raise NotImplementedError('-  Message function not supported yet!')
-      bo      = bosi+bopi+bopp
+      bo       = bosi+bopi+bopp
       return bo,bosi,bopi,bopp
 
   def get_bond_energy(self):
@@ -637,7 +640,7 @@ class MPNN(ReaxFF):
               'vdw_layer':self.vdw_layer,
               'MolEnergy':self.MolEnergy_,
               'rcut':self.rcut,
-              'rcutAngle':self.rcuta,
+              'rcutBond':self.rcuta,
               'rEquilibrium':self.re}
          js.dump(j,fj,sort_keys=True,indent=2)
          fj.close()
