@@ -1224,12 +1224,15 @@ class ReaxFF(object):
 
       if self.optword.find('novdw')>=0:
          cons = cons + ['gammaw','vdw1','rvdw','Devdw','alfa'] 
+      self.tor_v = ['tor2','tor3','tor4','V1','V2','V3','tor1','cot1','cot2'] 
+
       if self.optword.find('notor')>=0:
-         cons = cons + ['tor2','tor3','tor4','V1','V2','V3','tor1','cot1','cot2'] 
+         cons = cons + self.tor_v
+      self.ang_v = ['val1','val2','val3','val4','val5','val6','val7',
+                    'pen1','pen2','pen3','pen4',
+                    'coa1','coa2','coa3','coa4'] 
       if self.optword.find('noang')>=0:
-         cons = cons + ['val1','val2','val3','val4','val5','val6','val7',
-                        'pen1','pen2','pen3','pen4',
-                        'coa1','coa2','coa3','coa4'] 
+         cons = cons + self.ang_v
 
       if self.cons is None:
          self.cons = cons 
@@ -1275,13 +1278,13 @@ class ReaxFF(object):
           elif key=='atomic':
              self.p[k] = tf.clip_by_value(self.v[k],-99.9999,999.9999)
           elif key=='acut':
-             self.p[k] = tf.clip_by_value(self.v[k],0.0020,0.2000)
+             self.p[k] = tf.clip_by_value(self.v[k],0.0001,0.001)
           elif key=='hbtol':
-             self.p[k] = tf.clip_by_value(self.v[k],0.0001,0.1)
+             self.p[k] = tf.clip_by_value(self.v[k],0.0001,0.001)
           elif key=='cutoff':
-             self.p[k] = tf.clip_by_value(self.v[k],0.01,2.5)
+             self.p[k] = tf.clip_by_value(self.v[k],0.01,0.012)
           elif key=='ovun5':
-             self.p[k] = tf.clip_by_value(self.v[k],0.0,999.0*self.unit)
+             self.p[k] = tf.clip_by_value(self.v[k],0.0,60.0*self.unit)
           elif key=='ovun1':
              self.p[k] = tf.clip_by_value(self.v[k],0.1,2.0)
           elif key in ['boc4','boc5','vdw1']:
@@ -1454,17 +1457,17 @@ class ReaxFF(object):
                 # with tf.variable_scope('Neurons'):
                 trainable=True if key in opt else False       
                 if key in self.punit:
-                   if key in ['V1','V2','V3']:
-                      key = k.split('_')[1]
-                      k_  = key.split('-')
+                   if key in self.tor_v :
+                      key_ = k.split('_')[1]
+                      k_  = key_.split('-')
                       if k_[1]=='H' or k_[2]=='H':
                          self.v[k] = tf.constant(np.float32(self.unit*self.p_[k]),name=k)
                       else:
                          self.v[k] = tf.Variable(np.float32(self.unit*self.p_[k]),
                                                  trainable=trainable,name=k)   
-                   elif key in ['pen1','val1']:
-                      key = k.split('_')[1]
-                      k_  = key.split('-')
+                   elif key in self.ang_v:
+                      key_ = k.split('_')[1]
+                      k_   = key_.split('-')
                       if k_[1]=='H':
                          self.v[k] = tf.constant(np.float32(self.unit*self.p_[k]),name=k)
                       else:
@@ -1898,7 +1901,7 @@ class ReaxFF(object):
          self.be_layer_        = j['be_layer']
          self.vdw_layer_       = j['vdw_layer']
          rcut                  = j['rcut']
-         rcuta                 = j['rcutAngle']
+         rcuta                 = j['rcutBond']
          re                    = j['rEquilibrium']
          self.init_bonds()
       else:
